% SCRIPT "myUDDAE_Oscillator.m"
%
% This script defines the Oscillator with feedback delay, [1, Section 2].
%
% References:
%  [1] L. Fenzi and W. Michiels, "Robust stability optimization for linear 
%      delay systems in a probabilistic framework", Linear Algebra Appl. 
%      526: 1-26, 2017.
%
% Version 1.5, April, 2018. 
%               Luca Fenzi

%% SIZE OF THE LINEAR SYSTEM 
n=3;

%% NUMBER OF DISCRETE DELAYS
h=2;

%% LENGTH OF THE CONTROL PARAMETER
k=2;

%% STOCHASTIC DIMENSION OF THE PROBLEM
D=2;

%% DESCRIPTION OF THE RANDOM PARAMETERS
PCE=cell(1,D);
germ=cell(1,D);
    germ{1}='u';    % Undamping angular frequency (natural frequency)
    PCE{1}=[1,0.1];
    germ{2}='u';    % Damping ratio
    PCE{2}=[0.15,0.05];

%% NUMBER OF zeros & INF EIGENVALUES WHICH MUST BE DELETED
extra.Inf=1;    % n-rank of the leading matrix
extra.zeros=0;  % number of non-physical zeri eigenvalues 
                % which arise differentiating the distributed delay.
    
%% LEADING MATRIX
E=[ 1, 0, 0;...
    0, 1, 0;...
    0, 0, 0];

%% DISCRETE DELAY TERMS
TAU=@(omega) [0,1]; %INPUT discrete delays row vector TAU=[tau_{1}(omega),...,tau_{h}(omega)]>=0

A=cell(1,h);
A{1}=@(omega,K) [         0,                    1,  0;...
                -omega(1)^2, -2*omega(1)*omega(2),  0;...
                       K(1),                 K(2), -1];  
A{h}=@(omega,K) [0, 0, 0;...
                 0, 0, 1;...
                 0, 0, 0]; 

%% DERIVATIVES OF A{i} w.r.t K
A_prime=cell(k,h);
    % Derivive of A{i} w.r.t. K(1)
A_prime{1,1}=@(omega,K) [0, 0, 0;...
                         0, 0, 0;...
                         1, 0, 0];
A_prime{1,2}=@(omega,K) zeros(3);
    % Derivive of A{i} w.r.t. K(2)
A_prime{2,1}=@(omega,K) [0, 0, 0;...
                         0, 0, 0;...
                         0, 1, 0];
A_prime{2,2}=@(omega,K) zeros(3);
