%% MAIN FILE 
% 
% This script was used to evaluate the values in the third to the eigth
% columns in Table 3, Section 5.1 of [1] and to plot the right pane of
% Figure 7.
% These models were already analyzed in [2, Section 5].
%
% NB The results in the mat-file differs from the ones in the paper, since
% they were obtained by a normal laptop imposing fewer sample points.
%
% REMEMBER TO LOAD THE HANSO PROGRAM 
% free download at 
% http://www.cs.nyu.edu/overton/software/hanso/
% e.g. addpath('matlab/hanso') 
%
% REMEMBER TO LOAD the UDDAE_optimization
% free download at 
% http://twr.cs.kuleuven.be/research/software/delay-control/UDDAE_optimization/
% e.g. addpath('matlab/UDDAE_optimization') 
%
%  References:
%  [1] L. Fenzi and W. Michiels, "Robust stability optimization for linear 
%      delay systems in a probabilistic framework", Linear Algebra Appl. 
%      526: 1-26, 2017.
%  [2] W. Michiels, "Spectrum-based stability analysis and stabilisation of
%      systems described by dealy differential algebraic equations", IET
%      Control Theory Applications, 5, 1829 - 1842, (2011).
%
% Version 1.5, April, 2018. 
%               Luca Fenzi

%% 1 - LOAD HANSO 
%      http://www.cs.nyu.edu/overton/software/hanso/
%addpath('/home/luca/hanso') 

%% 2 - LOAD UDDAE
% https://people.cs.kuleuven.be/~luca.fenzi/LF_Software.htm
% addpath('/home/luca/UDDAE')
addpath(fileparts(pwd))

%% 3 - SPECIFY YOUR MODEL
myUDDAE=cell(1,4);
myUDDAE{1}='UDDAE_NC0_Static';
myUDDAE{2}='UDDAE_NC1_Dynamic';
myUDDAE{3}='UDDAE_NC2_Dynamic';

%% 4 - SPECIFY THE PARAMETER OF THE OPTIMIZATION PROBLEM
M_opt=100;   % Number of sample that we use for the optimization problem
N=20;       % Number of discretization points used in the Infinitesimal
            % Generator approach
c=[0, 10, 100,1000];
            % a=[0, 1, 5, 10, 25, 50];   % Parameters of the objective function
            
%% 5 - SPECIFY THE PARAMETER OF THE POSTPROCESSING ANALYSIS
M_post=1000; % Number of sample that we use for the postprocessing analysis

% INITIALIZATION
K=cell(1,4);
f=cell(1,3);
Mean=cell(1,4);        % Mean spectral abscissa
Variance=cell(1,4);    % Variance spectral abscissa
d_Mean=cell(1,4);      % Derivative mean spectral abscissa w.r.t. K
d_Variance=cell(1,4);  % Derivative Variance spectral abscissa w.r.t. K
alpha=cell(1,4);       % Nominal value of the spectral abscissa
d_alpha=cell(1,4);     % Nominal value of the gradient of the spectral abscissa



for j=1:3
    eval(myUDDAE{j})
    K{j}=zeros(k,length(c));   
    f{j}=zeros(1,length(c));   
    Mean{j}=zeros(1,length(c));    
    Variance{j}=zeros(1,length(c));   
    d_Mean{j}=zeros(k,length(c));  
    d_Variance{j}=zeros(k,length(c));  
    alpha{j}=zeros(1,length(c));       
    d_alpha{j}=zeros(k,length(c));
    for i=1:length(c)
        % Settings for HANSO
        [pars,options] = Optimization_myUDDAE(myUDDAE{j}, c(i), M_opt, N);
        % HANSO optimization
        [K{j}(:,i),f{j}(i)] = hanso(pars, options); 
        % Postprocessing analysis
        if j==1 && i==1
            [Mean{j}(i),Variance{j}(i), d_Mean{j}(:,i), d_Variance{j}(:,i), SpAbscissa]  =  MomentaSpectralAbscissa(myUDDAE{j}, K{j}(:,i), M_post, N);
        else
            [Mean{j}(i),Variance{j}(i), d_Mean{j}(:,i), d_Variance{j}(:,i)]  =  MomentaSpectralAbscissa(myUDDAE{j}, K{j}(:,i), M_post, N);
        end
        % Nominal Value
        [alpha{j}(i),d_alpha{j}(:,i)] =  NominalValue(myUDDAE{j}, K{j}(:,i), N);
    end
end

%% REMARK 
% Mean+c.Variance should be comparable with f otherwise you should re-run
% the optimization function with more sampling points.

%% WITHOUT CONTROL
figure
myUDDAE{4}='UDDAE_No_Control';
eval(myUDDAE{1})
K{4}=zeros(k,1); 
[Mean{4},Variance{4}, d_Mean{4}, d_Variance{4}, SpAbscissa_no_contol]  =  MomentaSpectralAbscissa(myUDDAE{1}, K{4}, M_post, N);
[alpha{4},d_alpha{4}] =  NominalValue(myUDDAE{1}, K{4}, N);
save('RESULTS_Static_vs_Dynamic.mat','myUDDAE','c','M_opt','M_post','N',...
    'Mean','Variance','K','f','d_Mean','d_Variance','alpha','d_alpha');
