%% MAIN FILE 
% 
% This script was used to evaluate the values in Table 4, [1, Section 5.2] 
% This system was already analyzed in [2, Section 7].
%
% NB The results in the mat-file differs from the ones in the paper, since
% they were obtained by a normal laptop imposing fewer sample points,
%
% REMEMBER TO LOAD THE HANSO PROGRAM 
% free download at 
% http://www.cs.nyu.edu/overton/software/hanso/
% e.g. addpath('matlab/hanso') 
%
% REMEMBER TO LOAD the UDDAE_optimization
% free download at 
% http://twr.cs.kuleuven.be/research/software/delay-control/UDDAE_optimization/
% e.g. addpath('matlab/UDDAE_optimization') 
%
% References:
%  [1] L. Fenzi and W. Michiels, "Robust stability optimization for linear 
%      delay systems in a probabilistic framework", Linear Algebra Appl. 
%      526: 1-26, 2017.
%  [2] W. Michiels, K. Engelborghs, P. Vansevenant, D. Roose, "Continuous 
%      pole placement for delay equations", Automatica 38:
%      747-761, 2002.
%
% Version 1.5, April, 2018. 
%               Luca Fenzi

%% 1 - LOAD HANSO 
%      http://www.cs.nyu.edu/overton/software/hanso/
%addpath('/home/luca/hanso') 

%% 2 - LOAD UDDAE
% https://people.cs.kuleuven.be/~luca.fenzi/LF_Software.htm
% addpath('/home/luca/UDDAE')
addpath(fileparts(pwd))

%% 3 - SPECIFY YOUR MODEL
myUDDAE='UDDAE_Distributed_Delays';
eval(myUDDAE)

%% 4 - SPECIFY THE PARAMETER OF THE OPTIMIZATION PROBLEM
M_opt=100;   % Number of sample that we use for the optimization problem
N=20;       % Number of discretization points used in the Infinitesimal
            % Generator approach
c=[0, 10, 100,1000];
            
%% 5 - SPECIFY THE PARAMETER OF THE POSTPROCESSING ANALYSIS
M_post=1000; % Number of sample that we use for the postprocessing analysis

% INITIALIZATION
K=zeros(k,length(c));           % Optimal controller
f=zeros(1,length(c));           % Optimal value of the Objective function
Mean=zeros(1,length(c));        % Mean spectral abscissa
Variance=zeros(1,length(c));    % Variance spectral abscissa
d_Mean=zeros(k,length(c));      % Derivative mean spectral abscissa w.r.t. K
d_Variance=zeros(k,length(c));  % Derivative Variance spectral abscissa w.r.t. K
alpha=zeros(1,length(c));       % Nominal value of the spectral abscissa
d_alpha=zeros(k,length(c));     % Nominal value of the gradient of the spectral abscissa

for i=1:length(c)
    % Settings for HANSO
    [pars,options] = Optimization_myUDDAE(myUDDAE, c(i), M_opt, N);
    % HANSO optimization
    [K(:,i),f(i)] = hanso(pars, options); 
    % Postprocessing analysis
    [Mean(i),Variance(i), d_Mean(:,i), d_Variance(:,i)]  =  MomentaSpectralAbscissa(myUDDAE, K(:,i), M_post, N);
    % Nominal Value
    [alpha(i),d_alpha(:,i)] =  NominalValue(myUDDAE, K(:,i), N);
end

%% REMARK 
% Mean+c.Variance should be comparable with f otherwise you should re-run
% the optimization function with more sampling points.

save('RESULTS_Distributed_Delays.mat','myUDDAE','c','M_opt','M_post','N',...
    'Mean','Variance','K','f','d_Mean','d_Variance','alpha','d_alpha');